@@ -17,6 +17,7 @@ from qiime2.plugin import (
     List,
     Str,
     Bool,
+    Threads,
 )
 from q2_types.multiplexed_sequences import (
     MultiplexedSingleEndBarcodeInSequence,
@@ -53,7 +54,7 @@ plugin.methods.register_function(
         'demultiplexed_sequences': SampleData[SequencesWithQuality],
     },
     parameters={
-        'cores': Int % Range(1, None),
+        'cores': Threads,
         'adapter': List[Str],
         'front': List[Str],
         'anywhere': List[Str],
@@ -144,7 +145,7 @@ plugin.methods.register_function(
         'demultiplexed_sequences': SampleData[PairedEndSequencesWithQuality],
     },
     parameters={
-        'cores': Int % Range(1, None),
+        'cores': Threads,
         'adapter_f': List[Str],
         'front_f': List[Str],
         'anywhere_f': List[Str],
@@ -263,9 +264,11 @@ plugin.methods.register_function(
         'barcodes': MetadataColumn[Categorical],
         'error_rate': Float % Range(0, 1, inclusive_start=True,
                                     inclusive_end=True),
+        'anchor_barcode': Bool,
         'batch_size': Int % Range(0, None),
         'minimum_length': Int % Range(1, None),
-        'cores': Int % Range(1, None),
+        'cut': Int,
+        'cores': Threads,
     },
     outputs=[
         ('per_sample_sequences', SampleData[SequencesWithQuality]),
@@ -282,6 +285,10 @@ plugin.methods.register_function(
                       'allowable error rate. The default value specified by '
                       'cutadapt is 0.1 (=10%), which is greater than '
                       '`demux emp-*`, which is 0.0 (=0%).',
+        'anchor_barcode': 'Anchor the barcode. The barcode is then '
+                          'expected to occur in full length at the beginning '
+                          '(5\' end) of the sequence. Can speed up '
+                          'demultiplexing if used.',
         'batch_size': 'The number of samples cutadapt demultiplexes '
                       'concurrently. Demultiplexing in smaller batches will '
                       'yield the same result with marginal speed loss, and '
@@ -291,6 +298,11 @@ plugin.methods.register_function(
                           'the cutadapt default of 0 has been overridden, '
                           'because that value produces empty sequence '
                           'records.',
+        'cut': 'Remove the specified number of bases from the sequences. '
+               'Bases are removed before demultiplexing. If a positive value '
+               'is provided, bases are removed from the beginning of the '
+               'sequences. If a negative value is provided, bases are removed '
+               'from the end of the sequences.',
     },
     output_descriptions={
         'per_sample_sequences': 'The resulting demultiplexed sequences.',
@@ -314,12 +326,16 @@ plugin.methods.register_function(
     parameters={
         'forward_barcodes': MetadataColumn[Categorical],
         'reverse_barcodes': MetadataColumn[Categorical],
+        'forward_cut': Int,
+        'reverse_cut': Int,
         'error_rate': Float % Range(0, 1, inclusive_start=True,
                                     inclusive_end=True),
+        'anchor_forward_barcode': Bool,
+        'anchor_reverse_barcode': Bool,
         'batch_size': Int % Range(0, None),
         'minimum_length': Int % Range(1, None),
         'mixed_orientation': Bool,
-        'cores': Int % Range(1, None),
+        'cores': Threads,
     },
     outputs=[
         ('per_sample_sequences', SampleData[PairedEndSequencesWithQuality]),
@@ -334,6 +350,32 @@ plugin.methods.register_function(
                             'per-sample barcodes for the forward reads.',
         'reverse_barcodes': 'The sample metadata column listing the '
                             'per-sample barcodes for the reverse reads.',
+        'forward_cut': 'Remove the specified number of bases from the forward '
+                       'sequences. Bases are removed before demultiplexing. '
+                       'If a positive value is provided, bases are removed '
+                       'from the beginning of the sequences. If a negative '
+                       'value is provided, bases are removed from the end of '
+                       'the sequences. If --p-mixed-orientation is set, then '
+                       'both --p-forward-cut and --p-reverse-cut must be '
+                       'set to the same value.',
+        'reverse_cut': 'Remove the specified number of bases from the reverse '
+                       'sequences. Bases are removed before demultiplexing. '
+                       'If a positive value is provided, bases are removed '
+                       'from the beginning of the sequences. If a negative '
+                       'value is provided, bases are removed from the end of '
+                       'the sequences. If --p-mixed-orientation is set, then '
+                       'both --p-forward-cut and --p-reverse-cut must be '
+                       'set to the same value.',
+        'anchor_forward_barcode': 'Anchor the forward barcode. The '
+                                  'barcode is then expected to occur in full '
+                                  'length at the beginning (5\' end) of the '
+                                  'forward sequence. Can speed up '
+                                  'demultiplexing if used.',
+        'anchor_reverse_barcode': 'Anchor the reverse barcode. The '
+                                  'barcode is then expected to occur in full '
+                                  'length at the beginning (5\' end) of the '
+                                  'reverse sequence. Can speed up '
+                                  'demultiplexing if used.',
         'error_rate': 'The level of error tolerance, specified as the maximum '
                       'allowable error rate.',
         'batch_size': 'The number of samples cutadapt demultiplexes '
@@ -347,7 +389,7 @@ plugin.methods.register_function(
                           'records.',
         'mixed_orientation': 'Handle demultiplexing of mixed orientation '
                              'reads (i.e. when forward and reverse reads '
-                             'coexist in the same file).'
+                             'coexist in the same file).',
     },
     output_descriptions={
         'per_sample_sequences': 'The resulting demultiplexed sequences.',
